@@ -71,7 +71,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 26720838 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 26915743 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -804,6 +804,17 @@ for CARD in /proc/asound/card[0-9]*; do
     done
 done
 
+# List the sysfs entries for all NVIDIA device functions
+# This info is useful to debug dynamic power management issues
+for subdir in `ls /sys/bus/pci/devices/ 2> /dev/null`; do
+    vendor_id=`cat /sys/bus/pci/devices/$subdir/vendor 2> /dev/null`
+    if [ "$vendor_id" = "0x10de" ]; then
+        append "/sys/bus/pci/devices/$subdir/power/control"
+        append "/sys/bus/pci/devices/$subdir/power/runtime_status"
+        append "/sys/bus/pci/devices/$subdir/power/runtime_usage"
+    fi
+done
+
 # List the mapping of DRM drivers to DRM device files
 (
     echo "____________________________________________"
@@ -933,6 +944,45 @@ else
     ) | $GZIP_CMD >> $LOG_FILENAME
 fi
 
+(
+    echo "____________________________________________"
+    echo ""
+    acpidump=`which acpidump 2> /dev/null | head -n 1`
+
+    if [ $? -eq 0 -a -x "$acpidump" ]; then
+
+        base64=`which base64 2> /dev/null | head -n 1`
+
+        if [ $? -eq 0 -a -x "$base64" ]; then
+
+            TEMP_FILENAME="acpidump-temp$$.log"
+
+            echo "$acpidump -o"
+            echo ""
+            $acpidump -o $TEMP_FILENAME 2> /dev/null
+
+            # make sure if data file is created
+            if [ -f "$TEMP_FILENAME" ]; then
+                $base64 $TEMP_FILENAME 2> /dev/null
+                echo ""
+
+                # remove the temporary file when complete
+                rm $TEMP_FILENAME 2> /dev/null
+            else
+                echo "Skipping acpidump output (can't create data file $TEMP_FILENAME)"
+                echo ""
+                # don't fail here, continue
+            fi
+        else
+            echo "Skipping acpidump output (base64 not found)"
+            echo ""
+        fi
+    else
+        echo "Skipping acpidump output (acpidump not found)"
+        echo ""
+    fi
+) | $GZIP_CMD >> $LOG_FILENAME
+
 (
     echo "____________________________________________"
 
